@@ -33,13 +33,13 @@
 typedef QList<KCModuleProxy *> ModuleList;
 
 /***********************************************************************/
-class KCModuleContainer::KCModuleContainerPrivate
+class Q_DECL_HIDDEN KCModuleContainer::KCModuleContainerPrivate
 {
 public:
     KCModuleContainerPrivate(const QStringList &mods)
         : modules(mods)
-        , tabWidget(0)
-        , topLayout(0)
+        , tabWidget(nullptr)
+        , topLayout(nullptr)
     {}
 
     QStringList modules;
